@@ -377,7 +377,7 @@ mrma <- function(coefficients, vcov, variances,  ...) {
   meta.method <- "REML" # Method for meta-analysis
   
   # Test if we are dealing with multivariate data
-  if (class(coefficients) == "numeric") {
+  if (inherits(coefficients, "numeric")) {
     coefficients <- data.frame(y=coefficients)
   }
   if (ncol(coefficients)==1) {
@@ -447,4 +447,17 @@ get.function <- function(x, ...) {
     return(x)
   else
     return(get(as.character(x), mode = "function"))
-}
\ No newline at end of file
+}
+
+# Convert factor to binary
+# In case the factor has more than 2 levels, by default the same occurs as in 
+# glm: the first level is assumed to be the failure, and all others successes.
+factor_as_binary <- function(x, failure_level = 1) {
+  if (!is.factor(x)) stop(paste0("x must be a factor, x was ", class(x)))
+  y <- rep(1, length(x))
+  y[x == levels(x)[failure_level]] <- 0
+  y[is.na(x)] <- NA
+  y
+}
+
+
