@@ -69,90 +69,10 @@ calcPredInt <- function(x, sigma2, tau2, k, level = 0.95) {
   return(out)
 }
 
-run_Bayesian_MA_oe <- function(x, pars, n.chains, verbose, ...) {
-  
-  # Truncate hyper parameter variance
-  pars$hp.mu.var = min(pars$hp.mu.var, 100)
-  
-  # Select studies where we have info on O, E and N
-  i.select1 <- which(!is.na(x$O) & !is.na(x$E) & !is.na(x$N))
-  
-  # Select studies where we only have info on O and E
-  i.select2 <- which(!is.na(x$O) & !is.na(x$E) & is.na(x$N))
-  
-  # Select studies where we have (estimated) information on log(OE) and its standard error
-  i.select3 <- which(!is.na(x$theta) & !is.na(x$theta.se) & is.na(x$O) & is.na(x$E))
-  
-  mvmeta_dat <- list(O = x$O, E = x$E)
-  
-  if (length(i.select1) > 0) {
-    mvmeta_dat$s1 <- i.select1
-    mvmeta_dat$N <- x$N
-  }
-  if (length(i.select2) > 0)
-    mvmeta_dat$s2 <- i.select2
-  if (length(i.select3) > 0) {
-    mvmeta_dat$s3 <- i.select3
-    mvmeta_dat$logOE <- x$theta
-    mvmeta_dat$logOE.se <- x$theta.se
-  }
-  
-  # Generate model
-  model <- generateBUGS.OE.discrete(N.type1 = length(i.select1), 
-                                    N.type2 = length(i.select2),
-                                    N.type3 = length(i.select3),
-                                    pars = pars, ...)
-  
-  # Generate initial values from the relevant distributions
-  model.pars <- generateHyperparametersMA(pars, ...)
-  
-  
-  inits <- generateMCMCinits(n.chains = n.chains, 
-                             model.pars = model.pars)
-  
-  jags.model <- runjags::run.jags(model = model, 
-                                  monitor = c("mu.tobs", "mu.oe", "pred.oe", "bsTau", "prior_bsTau", "prior_mu", "PED"), 
-                                  data = mvmeta_dat, 
-                                  n.chains = n.chains,
-                                  confidence = pars$level, # Which credibility intervals do we need?
-                                  silent.jags = !verbose,
-                                  inits = inits,
-                                  ...)
-  # cat(paste("\nPenalized expected deviance: ", round(x$PED,2), "\n"))
-  
-  # Check convergence
-  psrf.ul <-  jags.model$psrf$psrf[,2]
-  psrf.target <- jags.model$psrf$psrf.target
-  
-  if (sum(psrf.ul > psrf.target) > 0) {
-    warning(paste("Model did not properly converge! The upper bound of the convergence diagnostic (psrf) exceeds", 
-                  psrf.target, "for the parameters", 
-                  paste(rownames(jags.model$psrf$psrf)[which(psrf.ul > psrf.target)], " (psrf=", 
-                        round(jags.model$psrf$psrf[which(psrf.ul > psrf.target),2],2), ")", collapse = ", ", sep = ""),
-                  ". Consider re-running the analysis by increasing the optional arguments 'adapt', 'burnin' and/or 'sample'."  ))
-  }
-  
-  fit <- jags.model$summaries
-  
-  #Extract PED
-  fit.dev <- runjags::extract(jags.model,"PED")
-  txtLevel <- (pars$level*100)
-  
-  out <- list(numstudies = length(c(i.select1, i.select2, i.select3)), 
-              fit = jags.model, 
-              PED = sum(fit.dev$deviance) + sum(fit.dev$penalty),
-              est = fit["mu.oe", "Median"],
-              ci.lb  = fit["mu.oe", paste("Lower", txtLevel, sep = "")],
-              ci.ub  = fit["mu.oe", paste("Upper", txtLevel, sep = "")],
-              pi.lb  = fit["pred.oe", paste("Lower", txtLevel, sep = "")],
-              pi.ub  = fit["pred.oe", paste("Upper", txtLevel, sep = "")])
-  out
-  
-}
 
 
 
-generateHyperparametersMA <- function(x) {
+generateHyperparametersMA <- function(x, ...) {
   # Generate initial values from the relevant distributions
   model.pars <- list()
   model.pars[[1]] <- list(param = "mu.tobs", 
@@ -183,7 +103,6 @@ generateHyperparametersMA <- function(x) {
 }
 
 
-
 restore.c.var.hanley <- function(cstat, N.subjects, N.events, restore.method=4, g=NULL) {
   
   fHanley <- function(cstat, nstar, mstar, m, n) {
@@ -328,35 +247,3 @@ plotCalibration <- function(predy, obsy, modelname="Model",
   scatter
 }
 
-.initiateDefaultPars <- function(pars, type = "") {
-  pars.default <- list(level = 0.95,
-                       hp.mu.mean = 0, 
-                       hp.mu.var = 1000,
-                       hp.tau.min = 0,
-                       hp.tau.max = 100,
-                       hp.tau.mean = 0,
-                       hp.tau.sigma = 0.5,
-                       hp.tau.dist = "dunif", 
-                       hp.tau.df = 3, 
-                       correction = 0.5)
-  
-  if (type == "valmeta") {
-    pars.default$hp.tau.max = 2
-    pars.default$method.restore.c.se = 4
-    pars.default$model.cstat = "normal/logit"
-    pars.default$model.oe = "normal/log"  #Alternative: "poisson/log" or "normal/identity"
-  }
-  
-  if (!missing(pars)) {
-    for (i in 1:length(pars)) {
-      element <- ls(pars)[i]
-      pars.default[[element]] <- pars[[element]]
-    }
-  }
-  
-  if (pars.default$level < 0 | pars.default$level > 1) {
-    stop ("Invalid value for 'level'!")
-  } 
-  
-  return(pars.default)
-}
\ No newline at end of file
